@@ -673,3 +673,80 @@ Eigen_sqrt <- function(M){
   }
   Msqrt
 }
+
+#' Real Schur decomposition
+#' @description Real Schur decomposition of a square matrix.
+#'
+#' @param M real square matrix
+#'
+#' @return A list with the \code{T} and \code{U} matrices.
+#' @export
+#' @details See \href{https://eigen.tuxfamily.org/dox/classEigen_1_1RealSchur.html}{Eigen::RealSchur}.
+#'
+#' @examples
+#' library(EigenR)
+#' M <- cbind(c(3, 2, 3), c(1, 1, 1), c(5, 0, -2))
+#' schur <- Eigen_realSchur(M)
+#' T <- schur$T
+#' U <- schur$U
+#' M - U %*% T %*% t(U)
+Eigen_realSchur <- function(M) {
+  stopifnot(isSquareMatrix(M), isReal(M))
+  EigenR_realSchur(M)
+}
+
+
+#' Complex Schur decomposition
+#' @description Complex Schur decomposition of a square matrix.
+#'
+#' @param M real or complex square matrix
+#'
+#' @return A list with the \code{T} and \code{U} matrices.
+#' @export
+#' @details See \href{https://eigen.tuxfamily.org/dox/classEigen_1_1ComplexSchur.html}{Eigen::ComplexSchur}.
+#'
+#' @examples
+#' library(EigenR)
+#' M <- cbind(c(3, 2i, 1+3i), c(1, 1i, 1), c(5, 0, -2i))
+#' schur <- Eigen_complexSchur(M)
+#' T <- schur$T
+#' U <- schur$U
+#' M - U %*% T %*% t(Conj(U))
+Eigen_complexSchur <- function(M) {
+  stopifnot(isSquareMatrix(M), isRealOrComplex(M))
+  schur <- EigenR_complexSchur(Re(M), Im(M))
+  T <- schur[["T"]]
+  U <- schur[["U"]]
+  list(
+    "T" = T[["real"]] + 1i * T[["imag"]],
+    "U" = U[["real"]] + 1i * U[["imag"]]
+  )
+}
+
+#' Hessenberg decomposition
+#' @description Hessenberg decomposition of a square matrix.
+#'
+#' @param M real or complex square matrix
+#'
+#' @return A list with the \code{H} and \code{Q} matrices.
+#' @export
+#' @details See \href{https://eigen.tuxfamily.org/dox/classEigen_1_1HessenbergDecomposition.html}{Eigen::HessenbergDecomposition}.
+#'
+#' @examples
+#' library(EigenR)
+#' M <- cbind(c(3, 2i, 1+3i), c(1, 1i, 1), c(5, 0, -2i))
+#' Eigen_Hessenberg(M)
+Eigen_Hessenberg <- function(M) {
+  stopifnot(isSquareMatrix(M), isRealOrComplex(M))
+  if(isReal(M)) {
+    EigenR_Hessenberg_real(M)
+  } else {
+    hd <- EigenR_Hessenberg_cplx(Re(M), Im(M))
+    H <- hd[["H"]]
+    Q <- hd[["Q"]]
+    list(
+      "H" = H[["real"]] + 1i * H[["imag"]],
+      "Q" = Q[["real"]] + 1i * Q[["imag"]]
+    )
+  }
+}
