@@ -7,7 +7,7 @@
 # }
 
 isStrictPositiveInteger <- function(x){
-  all(x > 0 & (floor(x) == x))
+  all(x > 0 & (floor(x) == x) & !is.na(x))
 }
 
 isSquareMatrix <- function(M){
@@ -15,9 +15,13 @@ isSquareMatrix <- function(M){
 }
 
 isRealOrComplex <- function(M){
-  is.numeric(M) || is.complex(M)
+  (is.numeric(M) || is.complex(M)) && !anyNA(M)
 }
 
 isRealOrComplexScalar <- function(x){
   (is.numeric(x) || is.complex(x)) && length(x) == 1L && !is.na(x)
 }
+
+isReal <- function(M){
+  is.numeric(M) && !anyNA(M)
+}
